﻿<#  .Synopsis    Convert-PathWinToLinux.ps1 converts the Windows path in the clipboard to its Linux path
    .version     1.0 Powershell open source without any warranty powered by echiquierBriochin.fr
    .Description The clipboard must contain a path with Windows backslash "\"
    .Example     1. Copy a path "C:\Program Files\GIMP\bin\gimp-2.10.exe" without double quotes in the clipboard by Ctrl+C
                 2. Run this script
                 3. The clipboard contents the same path where backslashes are replaced with slashes. Paste it where you need.
    .I/O         Clipboard
    .Module      [ ] https://github.com/mgr32/PsISEProjectExplorer
                 [ ] https://raw.github.com/dfinke/PSharp
                 [x] https://mattmcnabb.github.io/Customize-The-ISE-With-Hotkeys
    .Shortcut    %windir%\system32\WindowsPowerShell\v1.0\PowerShell_ISE.exe "C:\Chess\Scid\PowerShell\Convert-PathWinToLinux.ps1"                 
 #>
Set-StrictMode -Version 2.0
<# Copy and paste the following 3 lines in the dark blue console. Only the first line about policy is mandatory.

Set-ExecutionPolicy -ExecutionPolicy RemoteSigned -Scope Process
Import-Module PsISEProjectExplorer # Project Explorer tab on the right of Windows PowerShell ISE
Import-Module PSharp               # Cursor on a function + Ctrl+Shift+X or on a variable + Ctrl+Shift+T

For ScriptCop:

Set-ExecutionPolicy -ExecutionPolicy bypass -Scope Process
Import-Module ScriptCop
cd C:\Chess\Scid\PowerShell
Test-Command ".\Convert-PathWinToLinux.ps1"
 #>

function Convert-PathWinToLinux([string]$strPath)
{
    $strPath = $strPath.Replace("\", "/") # Unix separator of folders
    Write-Verbose -Message "Path Linux  : $strPath" -Verbose
    Set-Clipboard $strPath
}

function Convert-PathWinToUri([string]$strPath)
{   # Press Ctrl to transform the path in its URI
    $filename = Read-Host "Filename"
    $strPath = Join-Path -Path $strPath -ChildPath $filename
    $strPath = $strPath.Replace("\", "/") # Unix separator of folders
    $strPath = "file:///$strPath"
    Write-Verbose -Message "URI         : $strPath" -Verbose
    Set-Clipboard $strPath
}

function Test-KeyPress # https://mattmcnabb.github.io/Customize-The-ISE-With-Hotkeys
{
    <#
        .SYNOPSIS
        Checks to see if a key or keys are currently pressed.

        .DESCRIPTION
        Checks to see if a key or keys are currently pressed. If all specified keys are pressed then will return true, but if 
        any of the specified keys are not pressed, false will be returned.

        .PARAMETER Keys
        Specifies the key(s) to check for. These must be of type "System.Windows.Forms.Keys"

        .EXAMPLE
        Test-KeyPress -Keys ControlKey

        Check to see if the Ctrl key is pressed

        .EXAMPLE
        Test-KeyPress -Keys ControlKey,ShiftKey

        Test if Ctrl and Shift are pressed simultaneously (a chord)

        .LINK
        Uses the Windows API method GetAsyncKeyState to test for keypresses
        http://www.pinvoke.net/default.aspx/user32.GetAsyncKeyState

        The above method accepts values of type "system.windows.forms.keys"
        https://msdn.microsoft.com/en-us/library/system.windows.forms.keys(v=vs.110).aspx

        .NOTES
        Original idea found here at 
        http://powershell.com/cs/blogs/tips/archive/2015/12/08/detecting-key-presses-across-applications.aspx
        2015/12/08: redirected to https://community.idera.com/

        .LINK
        2016-01-17: "Use Hotkeys to Customize the PowerShell ISE" by Matt McNabb
        https://mattmcnabb.github.io/Customize-The-ISE-With-Hotkeys


        .INPUTS
        System.Windows.Forms.Keys

        .OUTPUTS
        System.Boolean
    #>
    
    [CmdletBinding()]
    param
    (
        [Parameter(Mandatory = $true)]
        [ValidateNotNullOrEmpty()]
        [System.Windows.Forms.Keys[]]
        $Keys
    )
    
    # use the User32 API to define a keypress datatype
    $Signature = @'
    [DllImport("user32.dll", CharSet=CharSet.Auto, ExactSpelling=true)] 
    public static extern short GetAsyncKeyState(int virtualKeyCode); 
'@
    $API = Add-Type -MemberDefinition $Signature -Name 'Keypress' -Namespace Keytest -PassThru
    
    # test if each key in the collection is pressed
    $Result = foreach ($Key in $Keys)
    {
        [bool]($API::GetAsyncKeyState($Key) -eq -32767)
    }
    
    # if all are pressed, return true, if any are not pressed, return false
    $Result -notcontains $false
}

#region main
[string]$strPath = Get-Clipboard
if ($strPath.Length -eq 0)       { Write-Warning "The clipboard does not contain a Windows path" -WarningAction Stop}
if (-not $strPath.Contains("\")) { Write-Warning "The clipboard does not contain any backslash"  -WarningAction Stop}
Write-Verbose -Message "Path Windows: $strPath" -Verbose

if (Test-KeyPress -Keys ControlKey) { Convert-PathWinToUri $strPath }
else { Convert-PathWinToLinux $strPath }
Write-Verbose -Message "The clipboard has been successfully updated!" -Verbose
#endregion main
